/*
	 RDB Object Structure:
	 .Publisher			- Publisher code:		value from 0-255 (0 by default)
	 .Version			- Version:				value from 1-3 (3 current version by default)
	 .Zip5				- 5 digit ZIP:			value from 0-99999 (0 by default)
	 .Zip4				- 4 digit ZIP:			value from 0-9999 (0 by default)
	 .Country			- Country code:			value from AA-ZZ
	 .State				- State:				value CC;State [CC = Country Code / State]
	 .Gender			- Gender:				value from 0-2 (1=Male, 2=Female)
	 .Subscriber		- Subscriber code		value from 0-255 (default 0)
	 .IncomeLow			- Lower income			value from 0-255 (default 0)
	 .IncomeHigh		- Higher income			value from 0-255 (default 0)
	 .AgeLow			- Low Age				value from 0-255 (default 0)
	 .AgeHigh			- High Age				value from 0-255 (default 0)
	 .Preferences[]		- Preferences			Array of preferences (64 different preferences)
*/

function encodeRDB(oRDB) {
	// Initial setup
	oRDB.Publisher = (oRDB.Publisher === undefined ? 0 : oRDB.Publisher);
	oRDB.Version = (oRDB.Version === undefined ? 0 : oRDB.Version);
	oRDB.Zip5 = (oRDB.Zip5 === undefined ? 0 : oRDB.Zip5);
	oRDB.Zip4 = (oRDB.Zip4 === undefined ? 0 : oRDB.Zip4);
	oRDB.Country = (oRDB.Country === undefined ? '' : oRDB.Country);
	oRDB.State = (oRDB.State === undefined ? '' : oRDB.State);
	oRDB.Gender = (oRDB.Gender === undefined ? 0 : oRDB.Gender);
	oRDB.Subscriber = (oRDB.Subscriber === undefined ? 0 : oRDB.Subscriber);
	oRDB.IncomeLow = (oRDB.IncomeLow === undefined ? 0 : oRDB.IncomeLow);
	oRDB.IncomeHigh = (oRDB.IncomeHigh === undefined ? 0 : oRDB.IncomeHigh);
	oRDB.AgeLow = (oRDB.AgeLow === undefined ? 0 : oRDB.AgeLow);
	oRDB.AgeHigh = (oRDB.AgeHigh === undefined ? 0 : oRDB.AgeHigh);
	oRDB.Preferences = (oRDB.Preferences === undefined ? 0 : oRDB.Preferences);

	var rRDB = '';

	// Publisher
	rRDB = rRDB + sprintf('%02x', oRDB.Publisher);

	// Version
	rRDB = rRDB + sprintf('%02x', oRDB.Version);

	// Zip5
	rRDB = rRDB + sprintf('%06x', oRDB.Zip5);

	// Zip4
	rRDB = rRDB + sprintf('%04x', oRDB.Zip4);

	// Country
	rRDB = rRDB + sprintf('%02x%02x', (oRDB.Country.length > 0 ? oRDB.Country.charCodeAt(0) : 0), (oRDB.Country.length > 0 ? oRDB.Country.charCodeAt(1) : 0));

	// State
	for (var i = 0; i < 15; i++)
		rRDB = rRDB + sprintf('%02x', (oRDB.State.length > i ? (oRDB.State.charAt(i) != ' ' ? oRDB.State.charCodeAt(i) : '-'.charCodeAt(0)) : (oRDB.State.length > 0 ? '-'.charCodeAt(0) : 0)));

	// Gender
	rRDB = rRDB + sprintf('%02x', oRDB.Gender);

	// Subscriber
	rRDB = rRDB + sprintf('%02x', oRDB.Subscriber);

	// Income
	rRDB = rRDB + sprintf('%02x', oRDB.IncomeLow) + sprintf('%02x', oRDB.IncomeHigh);

	// Age
	rRDB = rRDB + sprintf('%02x', oRDB.AgeLow) + sprintf('%02x', oRDB.AgeHigh);

	// Preferences
	var bTraits;
	for (var i = 0; i < 16; i++) {
		bTraits = (oRDB.Preferences[i * 4] === undefined ? 0 : oRDB.Preferences[i * 4]) + 2 * (oRDB.Preferences[i * 4 + 1] === undefined ? 0 : oRDB.Preferences[i * 4 + 1]) + 4 * (oRDB.Preferences[i * 4 + 2] === undefined ? 0 : oRDB.Preferences[i * 4 + 2]) + 8 * (oRDB.Preferences[i * 4 + 3] === undefined ? 0 : oRDB.Preferences[i * 4 + 3]);
		rRDB = rRDB + sprintf('%x', bTraits);
	}

	// FInal RDB
	return rRDB;
}

function encodeRDB_Targeting(oRDB) {
	// Initial setup
	oRDB.gender = (oRDB.gender === undefined ? "" : oRDB.gender);
	oRDB.zip = (oRDB.zip === undefined ? "" : oRDB.zip);
	oRDB.country = (oRDB.country === undefined ? "" : oRDB.country);
	oRDB.state = (oRDB.state === undefined ? "" : oRDB.state);

	oRDB.age = (oRDB.age === undefined ? "" : oRDB.age);
	oRDB.education = (oRDB.education === undefined ? "" : oRDB.education);
	oRDB.income = (oRDB.income === undefined ? "" : oRDB.income);
	oRDB.spendinpower = (oRDB.spendinpower === undefined ? "" : oRDB.spendinpower);
	oRDB.maritalstatus = (oRDB.maritalstatus === undefined ? "" : oRDB.maritalstatus);
	oRDB.job = (oRDB.job === undefined ? "" : oRDB.job);
	oRDB.locationradius = (oRDB.locationradius === undefined ? "" : oRDB.locationradius);
	oRDB.smartphoneuser = (oRDB.smartphoneuser === undefined ? "" : oRDB.smartphoneuser);
	oRDB.tabletuser = (oRDB.tabletuser === undefined ? "" : oRDB.tabletuser);
	oRDB.babyagerange = (oRDB.babyagerange === undefined ? "" : oRDB.babyagerange);
	oRDB.buyonlinerate = (oRDB.buyonlinerate === undefined ? "" : oRDB.buyonlinerate);

	oRDB.home = (oRDB.home === undefined ? "" : oRDB.home);
	oRDB.auto = (oRDB.auto === undefined ? "" : oRDB.auto);
	oRDB.beauty = (oRDB.beauty === undefined ? "" : oRDB.beauty);
	oRDB.cinema = (oRDB.cinema === undefined ? "" : oRDB.cinema);
	oRDB.design = (oRDB.design === undefined ? "" : oRDB.design);
	oRDB.economy = (oRDB.economy === undefined ? "" : oRDB.economy);
	oRDB.fashion = (oRDB.fashion === undefined ? "" : oRDB.fashion);
	oRDB.fiction = (oRDB.fiction === undefined ? "" : oRDB.fiction);
	oRDB.food = (oRDB.food === undefined ? "" : oRDB.food);
	oRDB.green = (oRDB.green === undefined ? "" : oRDB.green);
	oRDB.hitech = (oRDB.hitech === undefined ? "" : oRDB.hitech);
	oRDB.luxury = (oRDB.luxury === undefined ? "" : oRDB.luxury);
	oRDB.motors = (oRDB.motors === undefined ? "" : oRDB.motors);
	oRDB.healthcare = (oRDB.healthcare === undefined ? "" : oRDB.healthcare);
	oRDB.travel = (oRDB.travel === undefined ? "" : oRDB.travel);
	oRDB.videogames = (oRDB.videogames === undefined ? "" : oRDB.videogames);

	var rRDB = '';

	//altro
	rRDB = rRDB + "sd1=" + oRDB.gender + "|";
	rRDB = rRDB + "sd2=" + oRDB.zip + "|";
	rRDB = rRDB + "sd3=" + oRDB.country + "|";
	rRDB = rRDB + "sd4=" + oRDB.state + "|";

	//targeting
	rRDB = rRDB + "sd5=" + oRDB.age + "|";
	rRDB = rRDB + "sd6=" + oRDB.education + "|";
	rRDB = rRDB + "sd7=" + oRDB.income + "|";
	rRDB = rRDB + "sd8=" + oRDB.spendinpower + "|";
	rRDB = rRDB + "sd9=" + oRDB.maritalstatus + "|";
	rRDB = rRDB + "sd10=" + oRDB.job + "|";
	rRDB = rRDB + "sd11=" + oRDB.locationradius + "|";
	rRDB = rRDB + "sd12=" + oRDB.smartphoneuser + "|";
	rRDB = rRDB + "sd13=" + oRDB.tabletuser + "|";
	rRDB = rRDB + "sd14=" + oRDB.babyagerange + "|";
	rRDB = rRDB + "sd15=" + oRDB.buyonlinerate + "|";

	//interessi
	rRDB = rRDB + "i1=" + oRDB.home + "|";
	rRDB = rRDB + "i2=" + oRDB.auto + "|";
	rRDB = rRDB + "i3=" + oRDB.beauty + "|";
	rRDB = rRDB + "i4=" + oRDB.cinema + "|";
	rRDB = rRDB + "i5=" + oRDB.design + "|";
	rRDB = rRDB + "i6=" + oRDB.economy + "|";
	rRDB = rRDB + "i7=" + oRDB.fashion + "|";
	rRDB = rRDB + "i8=" + oRDB.fiction + "|";
	rRDB = rRDB + "i9=" + oRDB.food + "|";
	rRDB = rRDB + "i10=" + oRDB.green + "|";
	rRDB = rRDB + "i11=" + oRDB.hitech + "|";
	rRDB = rRDB + "i12=" + oRDB.luxury + "|";
	rRDB = rRDB + "i13=" + oRDB.motors + "|";
	rRDB = rRDB + "i14=" + oRDB.healthcare + "|";
	rRDB = rRDB + "i15=" + oRDB.travel + "|";
	rRDB = rRDB + "i16=" + oRDB.videogames;

	//console.log("rRDB = " + rRDB);

	// Final RDB
	return rRDB;
}