/*
 *      NYRB JS Module:
 *          add_to_home.js
 *
 *      desc:
 *          This file supports the Add to Home Screen feature on the home page
 *
 */

define( ['jquery', 'util', 'addtohome', 'cookie' ], function ( $, util, addtohome, cookie ) {

	var debug = util.debug,
		_addtohome_dismissed = false,
		_cookie_settings = {
			expires : 10*365,		//expires in 10 days
			path    : '/'			//The value of the path attribute of the cookie 
									//(default: path of page that created the cookie)
		},
		_is_iphone = (window.navigator.userAgent.indexOf('iPhone') != -1),
		_is_ipad = (window.navigator.userAgent.indexOf('iPad') != -1)
	;

	if ((_is_ipad === true) || (_is_iphone === true)) {

		if (_is_iphone === true) {
			$('.addtohome_promo_tablet').remove();
		} else if (_is_ipad === true) {
			$('.addtohome_promo_phone').remove();
		}

		// The module will only be available for iPhone / iPad
		_check_cookie();
		_update_promo();
		$('.addtohome_promo_outermost').css({
			'overflow': 'visible',
			'height': 'auto'
		});
		_bind_click_events();

	} else {

		// If the user is on a desktop computer, remove the widget
		$('.addtohome_promo_outermost').remove();

	}

	/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	function _check_cookie() {

		// Detect if the user has already interacted with the Add to Home Screen widget

		if ($.cookie("addtohome_dismissed")) {

			_addtohome_dismissed = $.cookie("addtohome_dismissed");

		} else {

			_set_cookie({
				'addtohome_dismissed': 'false'
			});

		}

	}

	/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	function _update_promo() {

		// Remove the Add to Home promo if it has already been dismissed

		if (_addtohome_dismissed === 'true') {
			$('.addtohome_promo_outermost').remove();
		}

	}

	/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	function _set_cookie( args ) {

		$.cookie("addtohome_dismissed", args.addtohome_dismissed, _cookie_settings);
		_addtohome_dismissed = args.addtohome_dismissed;

	}

	/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	function _bind_click_events() {

		$('.addtohome_promo .text a').on('click', function (e) {

			e.preventDefault();

			debug('Click add');

			document.title = 'NYRB';

			addToHome.show(true);

		});

		$('.addtohome_promo .close a').on('click', function (e) {

			e.preventDefault();

			_set_cookie({
				'addtohome_dismissed': 'true'
			});

			_update_promo();

			debug('Click close');

		});

	}

	/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

});	
