/*
 *      NYRB JS Module:
 *          browse_filter.js
 *
 *      desc:
 *          This file contains various functions needed by the Browse UI.
 *
 */

define( ['jquery', 'util', 'resize' ], function ( $, util, resize ) {

	var _initialized = true,
		debug = util.debug,
		_thresholds = {
			'window': {
				'width': 768
			}
		},
		$module = $('#browse_filters');

	_init();

	/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	function _init() {

		// debug('Browse Filter initializing.');

		resize.register({
			'name': 'device.on_resize',
			'callback': _on_resize
		});

		if ($('body').hasClass('browse_authors')) {

			// Browse authors doesn't have a title sort, so remove this button
			$('.sort_phone .dropdown-menu li.title').remove();

		}

		$('.sort_phone li.title a').on('click', function(){

			// debug('Sort by title');
			var url = $('#h-title a').attr('href');
			location.href = url;

		});

		$('.sort_phone li.author a').on('click', function(){

			// debug('Sort by author');
			var url = $('#h-author a').attr('href');
			location.href = url;

		});

	}

	/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	function _on_resize() {

		_reset_ui();

	}

	/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	function _reset_ui() {

		var win_w = $(window).width();

		if (win_w > _thresholds.window.width) {

			if ($module.hasClass('in')) {

				// Collapse the Filter block if the user transitions to a device
				// or window size greater than the threshold

				$module
					.removeClass('in')
					.attr('style','');

			}

		}

	}

	/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

});	

