/*
 *      NYRB JS Module:
 *          resize.js
 *
 *      desc:
 *          This file contains various functions needed by the Browse UI.
 *
 */

define( ['jquery', 'util', 'throttledresize' ], function ( $, util, throttledresize ) {

    // private vars
    var debug = util.debug,
        _callbacks = [],
        _events_bound = false,
        _initialized = false;

    /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

    // Init
    // decrease the firing rate to a maximum of 30fps
    // $.event.special.throttledresize.threshold = 1;
    // 2 <=> 20fps, 3 <=> 15fps, ...

    /* Disable throttle due to inconsistent initialization in IE8 */
    
	$(window).on("throttledresize", function( event ){
		invoke_callbacks();
   	});
    

    _bind_events();

    /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

    function _bind_events() {

        // debug('globalresize: bind events');

        // Exit if this module has already been initialized
        if ( _events_bound ) return true;

        /*$(window).resize(function(){

            invoke_callbacks();

        });*/

        _events_bound = true;

    }

    /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

    function invoke_callbacks() {

        // debug( _callbacks );
        // debug( 'resize' );

        for (var i in _callbacks) {

            _callbacks[i]();

        }

    }

    /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

    function _register( callback_object ) {

        var is_registered = false;

        // Attempt to bind events in case register() is invoked before 
        // this module is initialized
        _bind_events();

        if (callback_object.name in _callbacks) {

            is_registered = true;

        }

        if ( !is_registered ) {

            _callbacks[callback_object.name] = callback_object.callback;

        } else {

            debug( 'Error: Callback ' + callback_object.name + ' is already registered.' );

        }

        // debug( 'Success: Callback ' + callback_object.name + ' registered.' );

    }

    /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

    /* return public-facing methods and/or vars */
    return {
        register : _register
    };

});